import 'package:flutter/src/widgets/framework.dart';

import 'apptics_flutter_platform_interface.dart';
import 'apptics_flutter_util.dart';

class AppticsFlutter {
  /// This method allows you to include custom information with your crash report that can help you troubleshoot the issue.

  /// @param properties any object that is conforms to JSON Encoding

  Future<void> setCrashCustomProperty(Map<String, dynamic> properties) {
    return AppticsFlutterPlatform.instance.setCrashCustomProperty(properties);
  }

  ///  This method will show the user the privacy options that are built into the Apptics SDK.

  Future<void> presentPrivacyReviewPopup() {
    return AppticsFlutterPlatform.instance.presentPrivacyReviewPopup();
  }

  /// This method opens the screen where the user can change their analytic privacy settings.

  Future<void> openPrivacySettings() {
    return AppticsFlutterPlatform.instance.openPrivacySettings();
  }

  /// Specify a user identifier which will be used to identify the user in the future. We recommend you use a unique userID.

  /// - Warning:
  /// To protect users privacy, please do not pass any personally identifiable information to this method.

  /// @param user_id String

  Future<void> setUser(String user_id) {
    return AppticsFlutterPlatform.instance.setUser(user_id);
  }

  /// Returns the enum TrackingState for the current user:
  /// noTracking,
  /// usageAndCrashTrackingWithPII,
  /// onlyUsageTrackingWithPII,
  /// onlyCrashTrackingWithPII,
  /// usageAndCrashTrackingWithoutPII,
  /// onlyUsageTrackingWithoutPII,
  /// onlyCrashTrackingWithoutPII
  /// @return TrackingState

  Future<TrackingState?> getTrackingState() {
    return AppticsFlutterPlatform.instance.getTrackingState();
  }

  /// Set tracking state for the current user.

  /// @param state TrackingState

  Future<void> setTrackingState(TrackingState state) {
    return AppticsFlutterPlatform.instance.setTrackingState(state);
  }

  /// Returns the logged-in status of the user associated with the device.

  /// @return true if logged in else false.

  Future<bool?> isUserLoggedIn() {
    return AppticsFlutterPlatform.instance.isUserLoggedIn();
  }

  /// Use this method to track an event. Make sure you give meaningful names for events and their groups

  /// @param eventName name of the Occuring Event
  /// @param eventGroup name of the Group
  /// @param properties any object that is conforms to JSON Encoding

  Future<void> addEvent(
      String? event, String? group, Map<String, dynamic>? properties) {
    return AppticsFlutterPlatform.instance.addEvent(event, group, properties);
  }

  /// Use this method to track the attached screen.

  /// @param screen_name String (Enter the name of the screen you want to track)

  Future<void> screenAttached(String screen_name) {
    return AppticsFlutterPlatform.instance.screenAttached(screen_name);
  }

  /// Use this method to track the screen that is being detached.

  /// @param screen_name String (Enter the name of the screen you want to track)

  Future<void> screenDetached(String screen_name) {
    return AppticsFlutterPlatform.instance.screenDetached(screen_name);
  }

  /// Call the below method on an appropriate screen in your app.
  /// This will present a pop-up only if the app has crashed in the previous sessions while the crash tracking was disabled.

  Future<void> showLastSessionCrashedPopup() {
    return AppticsFlutterPlatform.instance.showLastSessionCrashedPopup();
  }

  /// Use this method to set the language for the Analytics SDK. If the language is not found in the resource bundle, the default language will be selected.
  /// @param lang (code) String.

  Future<void> setDefaultLanguage(String lang) {
    return AppticsFlutterPlatform.instance.setDefaultLanguage(lang);
  }

  /// To show version update alert with respect to the configuration in web console.
  /// @param context [BuildContext]
  /// This method should be invoked after setting the theme and creating the navigator in a Flutter application.
  /// The in-app update functionality in Flutter does not currently provide support for Material3.
  Future<void> checkAndUpdateAlert(BuildContext context) async {
    return AppticsFlutterPlatform.instance.checkAndUpdateAlert(context);
  }

  /// Triggers the update action when the "Update" button is clicked.
  /// This method invokes the corresponding platform-specific implementation for handling the update action.
  Future<void> onClickUpdate() async {
    return AppticsFlutterPlatform.instance.onClickUpdate();
  }

  /// Triggers the reminder action when the "Reminder" button is clicked.
  /// This method invokes the corresponding platform-specific implementation for handling the update action.
  Future<void> onClickReminder() async {
    return AppticsFlutterPlatform.instance.onClickReminder();
  }

  /// Triggers the ignore action when the "Ignore" button is clicked.
  /// This method invokes the corresponding platform-specific implementation for handling the update action.
  Future<void> onClickIgnore() async {
    return AppticsFlutterPlatform.instance.onClickIgnore();
  }

  /// Executes the necessary actions when the "Non-Supported OS" alert is clicked.
  /// This method calls the appropriate platform-specific implementation to handle the Non-Supported OS alert action.
  Future<void> onClickNonSupportAlert() async {
    return AppticsFlutterPlatform.instance.onClickNonSupportAlert();
  }

  /// Sends the impression status for a specific [updateId].
  /// The update ID can be obtained from instances of [AppUpdateData] and [AppticsAppUpdateNotSupported].
  /// This method calls the platform-specific implementation to send the impression status with the provided update ID.
  Future<void> onSendImpressionStatus(String updateId) async {
    return AppticsFlutterPlatform.instance.onSendImpressionStatus(updateId);
  }

  /// To construct a custom user interface for In-App Update,
  /// @return Map<String, dynamic>? representing In-App Update values
  /// This method returns three types of responses: 1. Normal update data, 2. Non-Supported OS popup data and 3. null.
  /// You can determine the response type based on the value of the ['category'] string, where 1 represents Normal update data and 2 represents Non-Supported OS popup data.
  ///
  /// Below are the keys you can use to construct your custom UI.
  ///
  /// For Custom Alerts data (Normal update):
  /// 'updateid': The ID corresponding to a specific update configuration.
  /// 'currentversion': The version of the app installed on the device.
  /// 'featureTitle': The title or heading for the version alert.
  /// 'features': Update features or what's new.
  /// 'remindMeLaterText': Localized text for the "Remind Me Later" action.
  /// 'updateNowText': Localized text for the "Update" action.
  /// 'neverAgainText': Localized text for the "Ignore" action.
  /// The 'option' key determines the type of UI selected for this update in the web console:
  //
  /// option (1): Shows a flexible flow for Android in-app updates and a UI with update, remind later, and ignore actions for ZAnalytics in-app updates.
  /// option (2): Shows an immediate flow for Android in-app updates and a UI with update and remind later actions.
  /// option (3): Shows the ZAnalytics in-app update dialog by default, and the update action depends on the alertType (android/zanalytics).
  /// 'reminderDays': The number of days before showing the popup again if the user chooses "Remind Me Later." These days can be configured from the web console.
  //
  /// 'forceInDays': A custom store URL to redirect when the user taps "Update/Download." This can also be configured from the web console.
  //
  /// 'alertType': The type of the alert - Android in-app updates / ZAnalytics:
  //
  /// 0: ZAnalytics custom UI alert
  /// 1: ZAnalytics native UI alert
  /// 2: Android in-app updates
  /// 'customStoreUrl': You can redirect this URL to another store.
  //
  /// For the Non-Supported OS popup data:
  //
  /// 'title': The title of the popup.
  /// 'description': The description of the popup.
  /// 'continueBtTxt': Button text for the popup.
  /// 'alertType' in the Non-Supported OS popup determines the action:
  ///  0: Do Nothing
  ///  1: Install Later
  ///  2: Freeze
  /// 'updateid': The ID corresponding to a specific update configuration.

  /// ['updateId'] -Id corresponds to particular update configuration.

  /// The following action methods are available: [onClickUpdate], [onClickReminder], [onClickIgnore], [onClickNonSupportAlert] and [onSendImpressionStatus].

  Future<Map<String, dynamic>?> getInAppUpdateData() {
    return AppticsFlutterPlatform.instance.getInAppUpdateData();
  }



}
