import 'package:flutter/src/widgets/framework.dart';
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'apptics_flutter_method_channel.dart';
import 'apptics_flutter_util.dart';

abstract class AppticsFlutterPlatform extends PlatformInterface {
  /// Constructs a AppticsFlutterPlatform.
  AppticsFlutterPlatform() : super(token: _token);

  static final Object _token = Object();

  static AppticsFlutterPlatform _instance = MethodChannelAppticsFlutter();

  /// The default instance of [AppticsFlutterPlatform] to use.
  ///
  /// Defaults to [MethodChannelAppticsFlutter].
  static AppticsFlutterPlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [AppticsFlutterPlatform] when
  /// they register themselves.
  static set instance(AppticsFlutterPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<void> setCrashCustomProperty(Map<String, dynamic> properties) {
    throw UnimplementedError(
        '`setCrashCustomProperty` has not been implemented.');
  }

  Future<void> presentPrivacyReviewPopup() {
    throw UnimplementedError(
        '`presentPrivacyReviewPopup` has not been implemented.');
  }

  Future<void> openPrivacySettings() {
    throw UnimplementedError('`openPrivacySettings` has not been implemented.');
  }

  Future<void> setUser(String? user_id) {
    throw UnimplementedError('`setUser` has not been implemented.');
  }

  Future<TrackingState?> getTrackingState() {
    throw UnimplementedError('`getTrackingState` has not been implemented.');
  }

  Future<void> setTrackingState(TrackingState status) {
    throw UnimplementedError('`setTrackingState` has not been implemented.');
  }

  Future<bool?> isUserLoggedIn() {
    throw UnimplementedError('`isUserLoggedIn` has not been implemented.');
  }

  Future<void> addEvent(
      String? event, String? group, Map<String, dynamic>? properties) {
    throw UnimplementedError('`addEvent` has not been implemented.');
  }

  Future<void> screenAttached(String screen_name) {
    throw UnimplementedError('`screenAttached` has not been implemented.');
  }

  Future<void> screenDetached(String screen_name) {
    throw UnimplementedError('`screenDetached` has not been implemented.');
  }

  Future<void> showLastSessionCrashedPopup() {
    throw UnimplementedError(
        '`showLastSessionCrashedPopup` has not been implemented.');
  }

  Future<void> setDefaultLanguage(String lang) {
    throw UnimplementedError('`setDefaultLanguage` has not been implemented.');
  }

  Future<void> checkAndUpdateAlert(BuildContext context) {
    throw UnimplementedError('`checkAndUpdateAlert` has not been implemented.');
  }

  Future<void> onClickUpdate() {
    throw UnimplementedError('`onClickUpdate` has not been implemented.');
  }

  Future<void> onClickReminder() {
    throw UnimplementedError('`onClickReminder` has not been implemented.');
  }

  Future<void> onClickIgnore() {
    throw UnimplementedError('`onClickIgnore` has not been implemented.');
  }

  Future<void> onClickNonSupportAlert() {
    throw UnimplementedError(
        '`onClickNonSupportAlert` has not been implemented.');
  }

  Future<void> onSendImpressionStatus(String updateId) {
    throw UnimplementedError(
        '`onSendImpressionStatus` has not been implemented.');
  }

  Future<Map<String, dynamic>?> getInAppUpdateData() {
    throw UnimplementedError('`getInAppUpdateData` has not been implemented.');
  }
}
