class AppUpdateData {
  /// Id corresponds to particular update configuration.
  final String updateId;

  /// version of the app installed in device.
  final String currentVersion;

  /// version alert title or heading
  final String featureTitle;

  /// update features or what's new.
  final String features;

  /// localized remind later action text.
  final String remindMeLaterText;

  /// localized update action text.
  final String updateNowText;

  /// localized ignore action text.
  final String neverAgainText;

  /// Type of UI selected for this update in web console.
  /// option (1) - Shows flexible flow for android in-app updates and
  /// UI with update, remind later and ignore actions for Zanalytics in-app updates.
  ///
  /// option (2) - Shows immediate flow for android in-app updates and UI with update, remind later actions.
  ///
  /// option (3) - Shows Zanalytics in-app update dialog by default and update action is depending on the alertType(android/zanalytics)
  ///
  String option;

  /// Number of days before showing the popup again, if user chooses remind me later.
  /// days can be configured from the web console.
  final String reminderDays;

  /// custom store url to redirect when user taps update/download.
  /// can be configured from web console.
  final int forceInDays;

  /// Type of the alert. Android in-app updates / ZAnalytics
  ///
  ///  0 - ZAnalytics custom UI alert
  ///  1 - ZAnalytics native UI alert
  ///  2 - Android in-app updates
  ///
  int alertType;

  /// You can redirect that URL to another store.
  final String customStoreUrl;

  AppUpdateData({
    required this.updateId,
    required this.currentVersion,
    required this.featureTitle,
    required this.features,
    required this.remindMeLaterText,
    required this.updateNowText,
    required this.neverAgainText,
    required this.option,
    required this.reminderDays,
    required this.forceInDays,
    required this.alertType,
    this.customStoreUrl = "",
  });

  factory AppUpdateData.fromJson(Map<String, dynamic> json) {
    return AppUpdateData(
      updateId: json['updateid'],
      currentVersion: json['currentversion'],
      featureTitle: json['featureTitle'],
      features: json['features'],
      remindMeLaterText: json['remindMeLaterText'],
      updateNowText: json['updateNowText'],
      neverAgainText: json['neverAgainText'],
      option: json['option'],
      reminderDays: json['reminderDays'],
      forceInDays: json['forceInDays'],
      alertType: json['alertType'],
      customStoreUrl: json['customStoreUrl'],
    );
  }
}

class AppticsAppUpdateNotSupported {
  /// Title of the Popup
  final String title;

  /// Description of the Popup
  final String description;

  /// Button text for the popup
  final String continueBtTxt;

  /// Type of the alert. Android in-app updates / ZAnalytics
  ///
  ///  0 - Do Nothing
  ///  1 - Install Later
  ///  2 - Freeze
  final int alertType;

  /// Id corresponds to particular update configuration.
  final String updateId;

  AppticsAppUpdateNotSupported(
      {required this.title,
      required this.description,
      required this.continueBtTxt,
      required this.alertType,
      required this.updateId});

  factory AppticsAppUpdateNotSupported.fromJson(Map<String, dynamic> json) {
    return AppticsAppUpdateNotSupported(
        title: json['title'],
        description: json['description'],
        continueBtTxt: json['continueBtTxt'],
        alertType: json['alertType'],
        updateId: json['updateId']);
  }
}
